@@ -30,7 +30,7 @@ from botocore.compat import urljoin, json, quote
 
 
 logger = logging.getLogger(__name__)
-
+DEFAULT_TIMEOUT = 60
 
 class Endpoint(object):
     """
@@ -44,7 +44,7 @@ class Endpoint(object):
     """
 
     def __init__(self, service, region_name, host, auth, proxies=None,
-                 verify=True):
+                 verify=True, timeout=DEFAULT_TIMEOUT):
         self.service = service
         self.session = self.service.session
         self.region_name = region_name
@@ -55,6 +55,7 @@ class Endpoint(object):
             proxies = {}
         self.proxies = proxies
         self.http_session = Session()
+        self.timeout = timeout
         self._lock = threading.Lock()
 
     def __repr__(self):
@@ -127,8 +128,10 @@ class Endpoint(object):
             http_response = self.http_session.send(
                 request, verify=self.verify,
                 stream=operation.is_streaming(),
-                proxies=self.proxies)
+                proxies=self.proxies, timeout=self.timeout)
         except Exception as e:
+            logger.debug("Exception received when sending HTTP request.",
+                         exc_info=True)
             return (None, e)
         # This returns the http_response and the parsed_data.
         return (botocore.response.get_response(self.session, operation,
